@@ -186,24 +186,24 @@ int main(int argc, char **argv)
 
   if (!debug) {
     /* daemonize */
-    openlog("pomavold", LOG_NDELAY | LOG_PID, LOG_DAEMON);
     pid = fork();
-    if (pid < 0) ERR("fork()");
+    if (pid < 0) err(1, "fork()");
     if (pid > 0) return 0;
 
-    if (chdir("/") < 0) ERR("chdir() to / failed");
-    if (setsid() < 0) ERR("setsid()");
+    if (chdir("/") < 0) err(1, "chdir() to / failed");
+    if (setsid() < 0) err(1, "setsid()");
+
+    if (pid < 0) err(1, "fork()");
+    if (pid > 0) return 0;
+
+    close(0); close(1); close(2);
   }
 
   /* wait for devices to appear */
-  if (timeout > 0) {
-    if (debug)
-      printf("sleeping for %i seconds\n", timeout);
-    else
-      syslog(LOG_INFO, "sleeping for %i seconds\n", timeout);
+  if (timeout > 0) sleep(timeout);
 
-    sleep(timeout);
-  }
+  if (!debug) openlog("pomavold", LOG_NDELAY | LOG_PID, LOG_DAEMON);
+  if (user && !(pw = getpwnam(user))) ERRX("no such user: %s", user);
 
   /* open mixer */
   if ((i = snd_mixer_open(&mixer, 0)))
@@ -241,11 +241,6 @@ int main(int argc, char **argv)
   if ((fd = open(device, O_RDWR)) < 0)
     ERR("cannot open %s for reading and writing", device);
 
-  if (user) {
-    pw = getpwnam(user);
-    if (!pw) ERRX("no such user: %s", user);
-  }
-
   if (user) {
     /* drop privileges, chroot */
     if (initgroups(user, pw->pw_gid) < 0) ERR("initgroups()");
